
![Y2F console logo](https://user-images.githubusercontent.com/87245086/215366359-7b0a7f42-ccaa-44fd-9d19-d8c26399a2c0.png)


<br>
<br>

## About
____________________________
Y2F is a cross-platform command line utility that allow users to download YouTube videos in a MP4 or MP3 format. Y2F was tested on Ubuntu, Debian, and Windows 10.

<br>
<br>

## Requirements
___________________________

### [-] Python

<br>

To install Python go to this link: https://www.python.org/downloads/

<br>

After the installation, open your terminal and type:   **python** **--version**  &nbsp; *or* &nbsp;  **python3 --version**. <br>
If the version of Python is not displayed, then you must add Python to the <br>
'Environment Variables'.



<br>
<br>

### [-] PIP

To install PIP, open your terminal and type:  **sudo apt-get install python-pip** &nbsp; *or* &nbsp; **sudo apt-get install python3-pip**. <br>

<br>

After the installation, open your terminal and type:  **pip** **--version** . <br>
If the version of PIP is not displayed, then you must add PIP to the <br>
'Environment Variables'.


<br>
<br>

## Installation
___________________________

Enter the command on Windows:  &nbsp; **python -m pip install Y2F** 
<br/>
<br/>
Enter the command on Linux:  &nbsp; **pip install Y2F**

<br>
<br>

## Usage
__________________

In order to use Y2F open your terminal and type **Y2F**. After Y2F is opened, <br>
select one of the options and then press enter. When prompted to enter the <br>
youtube link, copy the link, paste it and then press enter. When prompted to <br> 
enter the **PATH WHERE THE FILE WILL BE SAVED** enter the directory where <br>
you want the file to be saved (e.g.  C:\Users\John\Desktop).

